@@ -220,6 +220,10 @@ class OptionReqType(enum.Enum):
     LIQUIDITY = 204
     LIQUIDITY_PLUS = 205
     IMPLIED_VOLATILITY_VERBOSE = 206
+    TRADE_QUOTE = 207
+    EOD_QUOTE_GREEKS = 208
+    EOD_TRADE_GREEKS = 209
+
     # PRO
     TRADE_GREEKS = 301
     GREEKS_SECOND_ORDER = 302
