@@ -94,14 +94,14 @@ def launch_terminal(username: str = None, passwd: str = None, use_bundle: bool =
 
 def check_download(auto_update: bool) -> bool:
     try:
-        if os.path.exists('ThetaTerminal.jar') or auto_update:
+        if not os.path.exists('ThetaTerminal.jar') or auto_update:
             jar = urllib.request.urlopen("https://download-latest.thetadata.us")
             with open('ThetaTerminal.jar', 'wb') as output:
                 output.write(jar.read())
                 output.close()
         return True
     except:
-        print('Unable to fetch the latest terminal version.')
+        print('Unable to fetch the latest terminal version. Please contact support.')
     return False
 
 
